abacusai.project_config — AbacusAI documentation

# abacusai.project_config

## Classes

`ProjectConfig` | Project-specific config for a feature group

## Module Contents

class abacusai.project_config.ProjectConfig(client, type=None, config={})

  Bases: `abacusai.return_class.AbstractApiClass`

  Project-specific config for a feature group

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - type (str) – Type of project config

    - config (ProjectFeatureGroupConfig) – Project-specific config for this feature group

  type = None
  config
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict